# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from image_cropping import ImageCroppingMixin

from .models import Slider, Picture


class PictureInline(ImageCroppingMixin, admin.StackedInline):
    model = Picture
    extra = 0
    fieldsets = (
        (_('general information'), {
            'fields': ('title', 'abstract', 'image', 'cropping', 'link')
        }),
        (_('visualization admin'), {
            'fields': ('status', 'ordering'),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'title', 'link'
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class SliderAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('name', 'slug', 'language',)
        }),
        (_('visualization admin'), {
            'fields': ('status', 'ordering'),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'name', 'slug', 'language'
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    prepopulated_fields = {'slug': ('name',)}
    inlines = (PictureInline,)


admin.site.register(Slider, SliderAdmin)
